pub struct Input {
pub server: Option<FHIRCanonical>,
pub client: Option<FHIRCanonical>,
pub resource: Option<CapabilityStatement>,
}Fields
server: Option<FHIRCanonical>A canonical reference to the server capability statement - use this if the implements is not invoked on an instance (or on the /metadata end-point)
client: Option<FHIRCanonical>A canonical reference to the client capability statement - use this if the implements is not invoked on an instance (or on the /metadata end-point)
resource: Option<CapabilityStatement>The client capability statement, provided inline